Introduction
============

**radish** is a *Behaviour Driven Development*-Tool completely written in python.

Radish aims to be a Gherkin compatible tool but also supports own useful features like Scenario Loops, Scenario Preconditions and variables.

You are new to radish?
Start with the Quick Tutorial
